#include "MyI2C.h"

/**
 * @brief i2c master initialization
 */
static esp_err_t i2c_master_init(void)
{
    int i2c_master_port = I2C_MASTER_NUM;
    i2c_config_t conf = {
        .mode = I2C_MODE_MASTER,
        .sda_io_num = I2C_MASTER_SDA_IO,
        .sda_pullup_en = GPIO_PULLUP_ENABLE,
        .scl_io_num = I2C_MASTER_SCL_IO,
        .scl_pullup_en = GPIO_PULLUP_ENABLE,
        .master.clk_speed = I2C_MASTER_FREQ_HZ,
        // .clk_flags = 0,          /*!< Optional, you can use I2C_SCLK_SRC_FLAG_* flags to choose i2c source clock here. */
    };
    esp_err_t err = i2c_param_config(i2c_master_port, &conf);
    if (err != ESP_OK) {
        return err;
    }
    return i2c_driver_install(i2c_master_port, conf.mode, I2C_MASTER_RX_BUF_DISABLE, I2C_MASTER_TX_BUF_DISABLE, 0);
}

/**
 * @brief i2c slave initialization
 */
static esp_err_t i2c_slave_init(void)
{
    int i2c_slave_port = I2C_SLAVE_NUM;
    i2c_config_t conf_slave = {
        .sda_io_num = I2C_SLAVE_SDA_IO,
        .sda_pullup_en = GPIO_PULLUP_ENABLE,
        .scl_io_num = I2C_SLAVE_SCL_IO,
        .scl_pullup_en = GPIO_PULLUP_ENABLE,
        .mode = I2C_MODE_SLAVE,
        .slave.addr_10bit_en = 0,
        .slave.slave_addr = ESP_SLAVE_ADDR,
    };
    esp_err_t err = i2c_param_config(i2c_slave_port, &conf_slave);
    if (err != ESP_OK) {
        return err;
    }
    return i2c_driver_install(i2c_slave_port, conf_slave.mode, I2C_SLAVE_RX_BUF_LEN, I2C_SLAVE_TX_BUF_LEN, 0);
}



void MyI2C_init(void) {
#if !CONFIG_IDF_TARGET_ESP32C3
    ESP_ERROR_CHECK(i2c_slave_init());
#endif
    ESP_ERROR_CHECK(i2c_master_init());

	ESP_LOGI("I2C->", "TASK Init.\n");
}
/***********************I2C_WriteByte********************************/
uint8_t I2C_WriteByte(unsigned char addr,unsigned char data)
{
/*  u16 tt;
	tt=0;
    while(LL_I2C_IsActiveFlag_BUSY(I2C1)) {
			tt++;
			if (tt>100) {
				return 1;
			}
    }
		
		tt=0;
    LL_I2C_GenerateStartCondition(I2C1);
    while(!LL_I2C_IsActiveFlag_MSL(I2C1)) { 
			tt++;
			if (tt>100) {
				return 2;
			}
    }
		
		tt=0;
    //I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_MODE_SELECT); 
    
    LL_I2C_TransmitData8(I2C1,OLED_ADDRESS);
    while(!LL_I2C_IsActiveFlag_ADDR(I2C1)) {
			tt++;
			if (tt>100) {
				return 3;
			}
    }
		
		tt=0;
		LL_I2C_ClearFlag_ADDR(I2C1);
    //I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_TRANSMITTER_MODE_SELECTED);
    
    LL_I2C_TransmitData8(I2C1,addr);
	  while (!LL_I2C_IsActiveFlag_TXE(I2C1)) {
			tt++;
			if (tt>100) {
				return 4;
			}
    }
		
		tt=0;
//		while (!LL_I2C_IsActiveFlag_BTF(I2C1));
		//I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_BYTE_TRANSMITTED);  
    
    LL_I2C_TransmitData8(I2C1,data); 
    while (!LL_I2C_IsActiveFlag_TXE(I2C1)) { 
			tt++;
			if (tt>100) {
				return 5;
			}
    }
		
//		while (!LL_I2C_IsActiveFlag_BTF(I2C1));
		//I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_BYTE_TRANSMITTED);  
    
    LL_I2C_GenerateStopCondition(I2C1);
*/		
	return 0;
}

/***********************I2C_WriteByte********************************/
uint8_t I2C_ReadByte(unsigned char addr,unsigned char *data)
{
/*  u16 tt;
	tt=0;
    while(LL_I2C_IsActiveFlag_BUSY(I2C1)) {
			tt++;
			if (tt>100){
				return 1;
			}
    }
		
		tt=0;
    LL_I2C_GenerateStartCondition(I2C1);
    while(!LL_I2C_IsActiveFlag_MSL(I2C1)) { 
			tt++;
			if (tt>100) {
				return 2;
			}
    }
		
		tt=0;
    //I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_MODE_SELECT); 
    
    LL_I2C_TransmitData8(I2C1,OLED_ADDRESS);
    while(!LL_I2C_IsActiveFlag_ADDR(I2C1)) {
			tt++;
			if (tt>100) {
				return 3;
			}
    }
		
		tt=0;
		LL_I2C_ClearFlag_ADDR(I2C1);
    //I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_TRANSMITTER_MODE_SELECTED);
    
    LL_I2C_TransmitData8(I2C1,addr);
	  while (!LL_I2C_IsActiveFlag_TXE(I2C1)) {
			tt++;
			if (tt>100) {
				return 4;
			}
    }
		
		tt=0;
//		while (!LL_I2C_IsActiveFlag_BTF(I2C1));
		//I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_BYTE_TRANSMITTED);  
    
    *data=LL_I2C_ReceiveData8(I2C1); 
    while (!LL_I2C_IsActiveFlag_TXE(I2C1)) { 
			tt++;
			if (tt>100) {
				return 5;
			}
    }
		
//		while (!LL_I2C_IsActiveFlag_BTF(I2C1));
		//I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_BYTE_TRANSMITTED);  
    
    LL_I2C_GenerateStopCondition(I2C1);
*/		
	return 0;
}

uint8_t I2C_ReadTemp(unsigned char addr,unsigned char *data)
{
/*  u16 tt;


  LL_I2C_GenerateStartCondition(I2C2);
		tt=0;
//		while (!LL_I2C_IsActiveFlag_BTF(I2C1));
		//I2C_CheckEvent(I2C1,I2C_EVENT_MASTER_BYTE_TRANSMITTED);

    *data=LL_I2C_ReceiveData8(I2C2);
    while (!LL_I2C_IsActiveFlag_TXE(I2C2)) {
			tt++;
			if (tt>100) {
				return 3;
			}
    }
    *(data+1)=LL_I2C_ReceiveData8(I2C2);
    while (!LL_I2C_IsActiveFlag_TXE(I2C2)) {
			tt++;
			if (tt>100) {
				return 4;
			}
    }

    LL_I2C_GenerateStopCondition(I2C2);
*/
	return 0;
}